Crate mnk_games

Crate mnk_games 

Representations of k-in-a-row games.

Modules

gravity
MnkGames with gravity, which restricts vertical stone placement.
variants
Well-known MnkGames.

Structs

MnkBoard
The board state of an m,n,k-game.
MnkGame
A standard m,n,k-game.

Enums

GameStatus
The current status of a game.
PlaceError
An error which can occur when trying to place a stone.
PlayError
Errors which may occur when playing a move in an m,n,k-game.
Player
One of two players.
Space
A space that can be played on by a Player.