#[non_exhaustive]pub enum PlaceError {
Occupied {
player: Player,
},
OutOfBounds {
row: usize,
column: usize,
},
}Expand description
An error which can occur when trying to place a stone.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Occupied
An error which can occur when the location already contains a Space::Stone.
Fields

player: PlayerThe player who owns the blocking Space::Stone.
OutOfBounds
An error which can occur when the intended location is not within the board’s bounds.