#[non_exhaustive]pub enum PlayError {
GameOver(GameStatus),
PlaceError(PlaceError),
RuleError {
message: String,
},
}Expand description
Errors which may occur when playing a move in an m,n,k-game.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GameOver(GameStatus)
An error which may occur when the game is already over.
PlaceError(PlaceError)
An error which may occur when a stone cannot be placed at the indicated position.
RuleError
An error which may occur when a move is against a game’s rules.