Representations of k-in-a-row games.
Modules
Structs
- MnkBoard
- The board state of an m,n,k-game.
- MnkGame
- A standard m,n,k-game.
Enums
- Game
Status - The current status of a game.
- Place
Error - An error which can occur when trying to place a stone.
- Play
Error - Errors which may occur when playing a move in an m,n,k-game.
- Player
- One of two players.
- Space
- A space that can be played on by a
Player.